Functions and Strings Mixed-Up Code Questions
----------------------------------------------

.. selectquestion:: Function_String_MixedUpCode_1_v2_sq
   :fromid: Function_String_MixedUpCode_1_v2, Function_String_MixedUpCode_1_v2_ac
   :toggle:

.. selectquestion:: Function_String_MixedUpCode_2_v2_sq
   :fromid: Function_String_MixedUpCode_2_v2, Function_String_MixedUpCode_2_v2_ac
   :toggle:

.. selectquestion:: Function_String_MixedUpCode_3_sq
   :fromid: Function_String_MixedUpCode_3, Function_String_MixedUpCode_3_ac
   :toggle:

.. selectquestion:: Function_String_MixedUpCode_4_sq
   :fromid: Function_String_MixedUpCode_4, Function_String_MixedUpCode_4_ac
   :toggle:

.. selectquestion:: Function_String_MixedUpCode_5_sq
   :fromid: Function_String_MixedUpCode_5, Function_String_MixedUpCode_5_ac
   :toggle:

.. selectquestion:: Function_String_MixedUpCode_6_sq
   :fromid: Function_String_MixedUpCode_6, Function_String_MixedUpCode_6_ac
   :toggle:

.. selectquestion:: Function_String_MixedUpCode_7_sq
   :fromid: Function_String_MixedUpCode_7, Function_String_MixedUpCode_7_ac
   :toggle:

.. selectquestion:: Function_String_MixedUpCode_8_sq
   :fromid: Function_String_MixedUpCode_8, Function_String_MixedUpCode_8_ac
   :toggle:
